@@ -24,7 +24,7 @@ module SiSU_Viz
       'www.benkler.org'
     end
     def color_band1
-      '"#ffffff"'      
+      '"#ffffff"'
     end
     def txt_hp
       'www.benkler.org'
@@ -55,7 +55,7 @@ available at<br /><a href="http://www.amazon.com/exec/obidos/tg/detail/-/0300110
 <a href="http://search.barnesandnoble.com/booksearch/isbnInquiry.asp?isbn=0300110561">Barnes & Noble</a><br />
 This book is Copyright Yochai Benkler © 2006<br />
 Under a Creative Commons License, that permits non-commercial use of this work, provided attribution is given.<br />
-<a href="http://creativecommons.org/licenses/by-nc-sa/2.5/">http://creativecommons.org/licenses/by-nc-sa/2.5/</a><br />#{widget_sisu}</center></font></td></tr></table>}
+<a href="http://creativecommons.org/licenses/by-nc-sa/2.5/">http://creativecommons.org/licenses/by-nc-sa/2.5/</a></center></font></td></tr></table>}
     end
   end
   class TeX
@@ -71,8 +71,6 @@ Under a Creative Commons License, that permits non-commercial use of this work,
     def owner_chapter
       "Document owner details"
     end
-    def stmp
-	    "\\copyright Ralph Amissah, licence GPL \\\\\n www.jus.uio.no/sisu/"
-    end
   end
 end
+__END__
